Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/ImageGraph/StaticGraph.php')
-rw-r--r--plugins/ImageGraph/StaticGraph.php20
1 files changed, 8 insertions, 12 deletions
diff --git a/plugins/ImageGraph/StaticGraph.php b/plugins/ImageGraph/StaticGraph.php
index 3cd7b738ee..1f74457e7d 100644
--- a/plugins/ImageGraph/StaticGraph.php
+++ b/plugins/ImageGraph/StaticGraph.php
@@ -9,17 +9,13 @@
namespace Piwik\Plugins\ImageGraph;
-use pData;
-use pImage;
+use CpChart\Chart\Data;
+use CpChart\Chart\Image;
use Piwik\Container\StaticContainer;
use Piwik\NumberFormatter;
use Piwik\Piwik;
use Piwik\BaseFactory;
-require_once PIWIK_INCLUDE_PATH . "/libs/pChart/class/pDraw.class.php";
-require_once PIWIK_INCLUDE_PATH . "/libs/pChart/class/pImage.class.php";
-require_once PIWIK_INCLUDE_PATH . "/libs/pChart/class/pData.class.php";
-
/**
* The StaticGraph abstract class is used as a base class for different types of static graphs.
*
@@ -45,11 +41,11 @@ abstract class StaticGraph extends BaseFactory
private $aliasedGraph;
/**
- * @var pImage
+ * @var Image
*/
protected $pImage;
/**
- * @var pData
+ * @var Data
*/
protected $pData;
protected $ordinateLabels;
@@ -102,7 +98,7 @@ abstract class StaticGraph extends BaseFactory
public function sendToDisk($filename)
{
$filePath = self::getOutputPath($filename);
- $this->pImage->Render($filePath);
+ $this->pImage->render($filePath);
return $filePath;
}
@@ -238,7 +234,7 @@ abstract class StaticGraph extends BaseFactory
protected function initpData()
{
- $this->pData = new pData();
+ $this->pData = new Data();
foreach ($this->ordinateSeries as $column => $data) {
$this->pData->addPoints($data, $column);
@@ -257,7 +253,7 @@ abstract class StaticGraph extends BaseFactory
protected function initpImage()
{
- $this->pImage = new pImage($this->width, $this->height, $this->pData);
+ $this->pImage = new Image($this->width, $this->height, $this->pData);
$this->pImage->Antialias = $this->aliasedGraph;
$this->pImage->setFontProperties(
@@ -347,7 +343,7 @@ abstract class StaticGraph extends BaseFactory
/**
* Global format method
*
* required to format y axis values using pcharts internal format callbacks
* @param $value
* @return mixed
*/
@@ -347,7 +343,7 @@ abstract class StaticGraph extends BaseFactory
* Global format method
*
- * required to format y axis values using pcharts internal format callbacks
+ * required to format y axis values using CpChart internal format callbacks
* @param $value
* @return mixed